@@ -6,7 +6,8 @@ slots = c(strategy = "character",
   acceleration = "character",
   tolerance = "numeric",
   acceleration.multiplier = "numeric",
-  maximum.iterations = "numeric"))
+  maximum.iterations = "numeric",
+  K = "numeric"))
 
 setMethod("initialize", "EM.Control",
 function(.Object, ...,
@@ -15,7 +16,8 @@ function(.Object, ...,
   acceleration,
   tolerance,
   acceleration.multiplier,
-  maximum.iterations)
+  maximum.iterations,
+  K)
 {
   # strategy.
 
@@ -91,6 +93,22 @@ function(.Object, ...,
   if (maximum.iterations < 1) {
     stop(sQuote("maximum.iterations"), " must be greater than 0!", call. = FALSE)
   }  
+  
+  # K.
+  
+  if (missing(K) || (length(K) == 0)) {
+    K <- as.integer(0)
+  }
+
+  if (!is.wholenumber(K)) {
+    stop(sQuote("K"), " integer is requested!", call. = FALSE)
+  }
+
+  length(K) <- 1
+
+  if (K < 0) {
+    stop(sQuote("K"), " must be greater or equal than 0!", call. = FALSE)
+  }    
 
   .Object@strategy <- strategy
   .Object@variant <- variant
@@ -98,6 +116,7 @@ function(.Object, ...,
   .Object@tolerance <- tolerance
   .Object@acceleration.multiplier <- acceleration.multiplier
   .Object@maximum.iterations <- maximum.iterations
+  .Object@K <- K
 
   rm(list = ls()[!(ls() %in% c(".Object"))])
 
@@ -137,6 +156,10 @@ function(object)
   cat("Slot \"maximum.iterations\":", "\n", sep = "")
 
   print(object@maximum.iterations, quote = FALSE)
+  
+  cat("Slot \"K\":", "\n", sep = "")
+
+  print(object@K, quote = FALSE)  
 
   rm(list = ls())
 }) ## show
@@ -659,8 +682,8 @@ function(.Object, ...,
     stop(sQuote("cmin"), " must be greater than 0!", call. = FALSE)
   }
 
-  if (cmin > cmax) {
-    stop(sQuote("cmin"), " must be less or equal than ", cmax, "!", call. = FALSE)
+  if (cmin >= cmax) {
+    stop(sQuote("cmax"), " must be greater than ", cmin, "!", call. = FALSE)
   }
 
   # Criterion.
