@@ -1,13 +1,6 @@
-#include <math.h>
-#include <float.h>
-
-#include <stdio.h>
-#include <ctype.h>
-#include <time.h>
-
-#include "base.h"
 #include "rebmvnormf.h"
-#include "emf.h"
+
+#include <math.h>
 
 // Perform necessary initializations.
 
@@ -1463,6 +1456,7 @@ int Rebmvnorm::EMInitialize()
         EM_TOL_,
         EM_am_,
         EM_max_iter_,
+		EM_K_,
         EM_strategy_,
         EM_variant_,
         EM_accel_);
